@@ -15,7 +15,7 @@
 ;;;### (autoloads nil "emms" "emms.el" (0 0 0 0))
 ;;; Generated autoloads from emms.el
 
-(if (fboundp 'register-definition-prefixes) (register-definition-prefixes "emms" '("emms-" "define-emms-" "with-current-emms-playlist")))
+(if (fboundp 'register-definition-prefixes) (register-definition-prefixes "emms" '("define-emms-" "emms-" "with-current-emms-playlist")))
 
 ;;;***
 
@@ -23,19 +23,15 @@
 ;;; Generated autoloads from emms-browser.el
 
 (autoload 'emms-browser "emms-browser" "\
-Launch or switch to the EMMS Browser.
-
-\(fn)" t nil)
+Launch or switch to the EMMS Browser." t nil)
 
 (autoload 'emms-smart-browse "emms-browser" "\
 Display browser and playlist.
 Toggle between selecting browser, playlist or hiding both. Tries
 to behave sanely if the user has manually changed the window
-configuration.
+configuration." t nil)
 
-\(fn)" t nil)
-
-(if (fboundp 'register-definition-prefixes) (register-definition-prefixes "emms-browser" '("emms-" "case-fold-string")))
+(if (fboundp 'register-definition-prefixes) (register-definition-prefixes "emms-browser" '("case-fold-string" "emms-")))
 
 ;;;***
 
@@ -43,19 +39,13 @@ configuration.
 ;;; Generated autoloads from emms-cache.el
 
 (autoload 'emms-cache-enable "emms-cache" "\
-Enable caching of Emms track data.
-
-\(fn)" t nil)
+Enable caching of Emms track data." t nil)
 
 (autoload 'emms-cache-disable "emms-cache" "\
-Disable caching of Emms track data.
-
-\(fn)" t nil)
+Disable caching of Emms track data." t nil)
 
 (autoload 'emms-cache-toggle "emms-cache" "\
-Toggle caching of Emms track data.
-
-\(fn)" t nil)
+Toggle caching of Emms track data." t nil)
 
 (if (fboundp 'register-definition-prefixes) (register-definition-prefixes "emms-cache" '("emms-cache")))
 
@@ -164,19 +154,13 @@ Toggle caching of Emms track data.
 ;;; Generated autoloads from emms-lyrics.el
 
 (autoload 'emms-lyrics-enable "emms-lyrics" "\
-Enable displaying emms lyrics.
-
-\(fn)" t nil)
+Enable displaying emms lyrics." t nil)
 
 (autoload 'emms-lyrics-disable "emms-lyrics" "\
-Disable displaying emms lyrics.
-
-\(fn)" t nil)
+Disable displaying emms lyrics." t nil)
 
 (autoload 'emms-lyrics-toggle "emms-lyrics" "\
-Toggle displaying emms lyrics.
-
-\(fn)" t nil)
+Toggle displaying emms lyrics." t nil)
 
 (if (fboundp 'register-definition-prefixes) (register-definition-prefixes "emms-lyrics" '("emms-lyrics")))
 
@@ -202,19 +186,13 @@ Toggle displaying emms lyrics.
 ;;; Generated autoloads from emms-mode-line.el
 
 (autoload 'emms-mode-line-enable "emms-mode-line" "\
-Turn on `emms-mode-line'.
-
-\(fn)" t nil)
+Turn on `emms-mode-line'." t nil)
 
 (autoload 'emms-mode-line-disable "emms-mode-line" "\
-Turn off `emms-mode-line'.
-
-\(fn)" t nil)
+Turn off `emms-mode-line'." t nil)
 
 (autoload 'emms-mode-line-toggle "emms-mode-line" "\
-Toggle `emms-mode-line'.
-
-\(fn)" t nil)
+Toggle `emms-mode-line'." t nil)
 
 (if (fboundp 'register-definition-prefixes) (register-definition-prefixes "emms-mode-line" '("emms-mode-line")))
 
@@ -233,9 +211,7 @@ Toggle `emms-mode-line'.
 ;;; Generated autoloads from emms-player-mpd.el
 
 (autoload 'emms-player-mpd-clear "emms-player-mpd" "\
-Clear the MusicPD playlist.
-
-\(fn)" t nil)
+Clear the MusicPD playlist." t nil)
 
 (autoload 'emms-player-mpd-connect "emms-player-mpd" "\
 Connect to MusicPD and retrieve its current playlist.
@@ -245,9 +221,7 @@ Afterward, the status of MusicPD will be tracked.
 This also has the effect of changing the current EMMS playlist to
 be the same as the current MusicPD playlist.  Thus, this
 function is useful to call if the contents of the EMMS playlist
-buffer get out-of-sync for some reason.
-
-\(fn)" t nil)
+buffer get out-of-sync for some reason." t nil)
 
 (autoload 'emms-player-mpd-show "emms-player-mpd" "\
 Describe the current EMMS track in the minibuffer.
@@ -297,7 +271,7 @@ rather than EMMS.
 ;;;;;;  (0 0 0 0))
 ;;; Generated autoloads from emms-player-simple.el
 
-(if (fboundp 'register-definition-prefixes) (register-definition-prefixes "emms-player-simple" '("emms-player-" "alsaplayer" "fluidsynth" "timidity" "mpg321" "mikmod" "playsound" "speexdec" "ogg123" "define-emms-simple-player")))
+(if (fboundp 'register-definition-prefixes) (register-definition-prefixes "emms-player-simple" '("alsaplayer" "define-emms-simple-player" "emms-player-" "fluidsynth" "mikmod" "mpg321" "ogg123" "playsound" "speexdec" "timidity")))
 
 ;;;***
 
@@ -322,14 +296,10 @@ rather than EMMS.
 ;;; Generated autoloads from emms-playing-time.el
 
 (autoload 'emms-playing-time-enable-display "emms-playing-time" "\
-Display playing time on mode line.
-
-\(fn)" t nil)
+Display playing time on mode line." t nil)
 
 (autoload 'emms-playing-time-disable-display "emms-playing-time" "\
-Remove playing time from mode line.
-
-\(fn)" t nil)
+Remove playing time from mode line." t nil)
 
 (if (fboundp 'register-definition-prefixes) (register-definition-prefixes "emms-playing-time" '("emms-playing-time")))
 
@@ -339,7 +309,7 @@ Remove playing time from mode line.
 ;;;;;;  (0 0 0 0))
 ;;; Generated autoloads from emms-playlist-limit.el
 
-(if (fboundp 'register-definition-prefixes) (register-definition-prefixes "emms-playlist-limit" '("emms-playlist-limit-" "define-emms-playlist-limit")))
+(if (fboundp 'register-definition-prefixes) (register-definition-prefixes "emms-playlist-limit" '("define-emms-playlist-limit" "emms-playlist-limit-")))
 
 ;;;***
 
@@ -349,9 +319,7 @@ Remove playing time from mode line.
 
 (autoload 'emms-playlist-mode "emms-playlist-mode" "\
 A major mode for Emms playlists.
-\\{emms-playlist-mode-map}
-
-\(fn)" t nil)
+\\{emms-playlist-mode-map}" t nil)
 
 (if (fboundp 'register-definition-prefixes) (register-definition-prefixes "emms-playlist-mode" '("emms")))
 
@@ -361,7 +329,7 @@ A major mode for Emms playlists.
 ;;;;;;  (0 0 0 0))
 ;;; Generated autoloads from emms-playlist-sort.el
 
-(if (fboundp 'register-definition-prefixes) (register-definition-prefixes "emms-playlist-sort" '("emms-" "define-emms-playlist-sort")))
+(if (fboundp 'register-definition-prefixes) (register-definition-prefixes "emms-playlist-sort" '("define-emms-playlist-sort" "emms-")))
 
 ;;;***
 
@@ -369,19 +337,13 @@ A major mode for Emms playlists.
 ;;; Generated autoloads from emms-score.el
 
 (autoload 'emms-score-enable "emms-score" "\
-Turn on emms-score.
-
-\(fn)" t nil)
+Turn on emms-score." t nil)
 
 (autoload 'emms-score-disable "emms-score" "\
-Turn off emms-score.
-
-\(fn)" t nil)
+Turn off emms-score." t nil)
 
 (autoload 'emms-score-toggle "emms-score" "\
-Toggle emms-score.
-
-\(fn)" t nil)
+Toggle emms-score." t nil)
 
 (if (fboundp 'register-definition-prefixes) (register-definition-prefixes "emms-score" '("emms-score")))
 
@@ -392,31 +354,19 @@ Toggle emms-score.
 
 (autoload 'emms-minimalistic "emms-setup" "\
 An Emms setup script.
-Invisible playlists and all the basics for playing media.
-
-\(fn)" nil nil)
+Invisible playlists and all the basics for playing media." nil nil)
 
 (autoload 'emms-all "emms-setup" "\
 An Emms setup script.
 Everything included in the `emms-minimalistic' setup and adds all
-the stable features which come with the Emms distribution.
-
-\(fn)" nil nil)
+the stable features which come with the Emms distribution." nil nil)
 
 (autoload 'emms-default-players "emms-setup" "\
-Set `emms-player-list' to `emms-setup-default-player-list'.
+Set `emms-player-list' to `emms-setup-default-player-list'." nil nil)
 
-\(fn)" nil nil)
+(autoload 'emms-devel "emms-setup" nil nil nil)
 
-(autoload 'emms-devel "emms-setup" "\
-
-
-\(fn)" nil nil)
-
-(autoload 'emms-standard "emms-setup" "\
-
-
-\(fn)" nil nil)
+(autoload 'emms-standard "emms-setup" nil nil nil)
 
 (if (fboundp 'register-definition-prefixes) (register-definition-prefixes "emms-setup" '("emms-setup-default-player-list")))
 
@@ -451,9 +401,7 @@ This function uses `emms-source-file-directory-tree-function'.
 
 (autoload 'emms-source-file-regex "emms-source-file" "\
 Return a regexp that matches everything any player (that supports
-files) can play.
-
-\(fn)" nil nil)
+files) can play." nil nil)
 
 (autoload 'emms-locate "emms-source-file" "\
 Search for REGEXP and display the results in a locate buffer
@@ -464,7 +412,7 @@ Search for REGEXP and display the results in a locate buffer
  (autoload 'emms-play-streamlist "emms-source-file" nil t)
  (autoload 'emms-add-streamlist "emms-source-file" nil t)
 
-(if (fboundp 'register-definition-prefixes) (register-definition-prefixes "emms-source-file" '("streamlist" "url" "emms-" "dire" "file" "find")))
+(if (fboundp 'register-definition-prefixes) (register-definition-prefixes "emms-source-file" '("dire" "emms-" "file" "find" "streamlist" "url")))
 
 ;;;***
 
@@ -490,27 +438,14 @@ Search for REGEXP and display the results in a locate buffer
  (autoload 'emms-add-playlist-directory-tree
           "emms-source-file" nil t)
 
-(if (fboundp 'register-definition-prefixes) (register-definition-prefixes "emms-source-playlist" '("pls-playlist" "playlist" "emms-" "m3u-playlist" "native-playlist")))
-
-;;;***
-
-;;;### (autoloads nil "emms-stream-info" "emms-stream-info.el" (0
-;;;;;;  0 0 0))
-;;; Generated autoloads from emms-stream-info.el
-
-(if (fboundp 'register-definition-prefixes) (register-definition-prefixes "emms-stream-info" '("emms-stream-info-")))
+(if (fboundp 'register-definition-prefixes) (register-definition-prefixes "emms-source-playlist" '("emms-" "m3u-playlist" "native-playlist" "playlist" "pls-playlist")))
 
 ;;;***
 
 ;;;### (autoloads nil "emms-streams" "emms-streams.el" (0 0 0 0))
 ;;; Generated autoloads from emms-streams.el
 
-(autoload 'emms-streams "emms-streams" "\
-Opens the EMMS Streams interface.
-
-\(fn)" t nil)
-
-(if (fboundp 'register-definition-prefixes) (register-definition-prefixes "emms-streams" '("emms-")))
+(if (fboundp 'register-definition-prefixes) (register-definition-prefixes "emms-streams" '("emms-streams")))
 
 ;;;***
 
@@ -533,24 +468,16 @@ Opens the EMMS Streams interface.
 ;;; Generated autoloads from emms-volume.el
 
 (autoload 'emms-volume-raise "emms-volume" "\
-Raise the speaker volume.
-
-\(fn)" t nil)
+Raise the speaker volume." t nil)
 
 (autoload 'emms-volume-lower "emms-volume" "\
-Lower the speaker volume.
-
-\(fn)" t nil)
+Lower the speaker volume." t nil)
 
 (autoload 'emms-volume-mode-plus "emms-volume" "\
-Raise volume and enable or extend the `emms-volume-minor-mode' timeout.
-
-\(fn)" t nil)
+Raise volume and enable or extend the `emms-volume-minor-mode' timeout." t nil)
 
 (autoload 'emms-volume-mode-minus "emms-volume" "\
-Lower volume and enable or extend the `emms-volume-minor-mode' timeout.
-
-\(fn)" t nil)
+Lower volume and enable or extend the `emms-volume-minor-mode' timeout." t nil)
 
 (if (fboundp 'register-definition-prefixes) (register-definition-prefixes "emms-volume" '("emms-volume-")))
 
@@ -609,7 +536,8 @@ Change PulseAudio volume by AMOUNT.
 
 ;;;***
 
-;;;### (autoloads nil nil ("emms-maint.el") (0 0 0 0))
+;;;### (autoloads nil nil ("emms-maint.el" "emms-stream-info.el")
+;;;;;;  (0 0 0 0))
 
 ;;;***
 
